Welcome to Orange3 Text Mining documentation!
=============================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/corpus-widget
   widgets/importdocuments
   widgets/guardian-widget
   widgets/nytimes
   widgets/pubmed
   widgets/twitter-widget
   widgets/wikipedia-widget
   widgets/preprocesstext
   widgets/bagofwords-widget
   widgets/similarityhashing
   widgets/sentimentanalysis
   widgets/tweetprofiler
   widgets/topicmodelling-widget
   widgets/corpusviewer
   widgets/wordcloud
   widgets/concordance
   widgets/docmap
   widgets/wordenrichment
   widgets/duplicatedetection

Scripting
---------

.. toctree::
   :maxdepth: 2

   scripting/corpus.rst
   scripting/preprocess.rst
   scripting/twitter.rst
   scripting/nyt.rst
   scripting/guardian.rst
   scripting/wikipedia.rst
   scripting/bagofwords.rst
   scripting/topicmodeling.rst
   scripting/tag.rst
   scripting/async.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

